# Licensed under a 3-clause BSD style license - see LICENSE.rst

"""
Lightweight utilities for working with spectroscopic data.
"""

# Affiliated packages may add whatever they like to this file, but
# should keep this content at the top.
# ----------------------------------------------------------------------------
from ._astropy_init import *
# ----------------------------------------------------------------------------

# For egg_info test builds to pass, put package imports here.
if not _ASTROPY_SETUP_:
    from .redshift import redshift
    from .accumulate import accumulate
    from .resample import resample
    from .downsample import downsample



# Autogenerated by Astropy-affiliated package speclite's setup.py on 2022-01-11 00:09:02 UTC
import datetime

version = "0.15"
githash = "3a8fd927abee381eb4a10361ed9d16a043a6b262"


major = 0
minor = 15
bugfix = 0

version_info = (major, minor, bugfix)

release = True
timestamp = datetime.datetime(2022, 1, 11, 0, 9, 2)
debug = False

astropy_helpers_version = "4.0.1"
